@@ -40,7 +40,8 @@ def code_length(spec: Dict, code_type: str) -> int:
 
 
 def add_bban_checksum(country_code: str, bban: str) -> str:
-    if country_code == "IT":
+    if country_code in ["IT", "SM"]:
+        # The IBAN of San Marino is covered by the Italian IBAN and uses the same checksum
         checksum = algorithms["IT:default"].compute(bban[1:])
         bban = checksum + bban[1:]
     elif country_code == "BE":
@@ -52,6 +53,9 @@ def add_bban_checksum(country_code: str, bban: str) -> str:
         bban = bban[:3] + bban[5:]
         checksum = algorithms["BE:default"].compute(bban)
         bban = bban + checksum
+    elif country_code == "FR":
+        checksum = algorithms["FR:default"].compute(bban)
+        bban = bban[0:21] + checksum
     return bban
 
 
@@ -223,9 +227,7 @@ class IBAN(common.Base):
             raise exceptions.InvalidChecksumDigits("Invalid checksum digits")
 
     def _validate_bban_checksum(self) -> None:
-        bank_registry = registry.get("bank_code")
-        assert isinstance(bank_registry, dict)
-        bank = bank_registry.get((self.country_code, self.bank_code), {})
+        bank = self.bank or {}
         algo_name = bank.get("checksum_algo", "default")
         algo = algorithms.get(f"{self.country_code}:{algo_name}")
         if algo is None:
@@ -326,6 +328,38 @@ class IBAN(common.Base):
         """str: The customer specific account-code"""
         return self._get_code(code_type="account_code")
 
+    @property
+    def bank(self) -> Optional[dict]:
+        bank_registry = registry.get("bank_code")
+        assert isinstance(bank_registry, dict)
+        return bank_registry.get((self.country_code, self.bank_code))
+
+    @property
+    def bank_name(self) -> Optional[str]:
+        """Optional[str]: The name of the bank associated with the IBAN bank code.
+
+        Examples:
+            >>> IBAN('DE89370400440532013000').bank_name
+            'Commerzbank'
+
+        .. versionadded:: 2022.04.2
+        """
+
+        return None if self.bank is None else self.bank["name"]
+
+    @property
+    def bank_short_name(self) -> Optional[str]:
+        """Optional[str]: The name of the bank associated with the IBAN bank code.
+
+        Examples:
+            >>> IBAN('DE89370400440532013000').bank_short_name
+            'Commerzbank Köln'
+
+        .. versionadded:: 2022.04.2
+        """
+
+        return None if self.bank is None else self.bank["short_name"]
+
 
 def add_bban_regex(country: str, spec: Dict) -> Dict:
     bban_spec = spec["bban_spec"]
