@@ -133,6 +133,8 @@ def test_iban_properties():
     assert iban.formatted == "DE42 4306 0967 7000 5341 00"
     assert iban.length == len(iban) == 22
     assert iban.country == countries.get(alpha_2="DE")
+    assert iban.bank_name == "GLS Gemeinschaftsbank"
+    assert iban.bank_short_name == "GLS Gemeinschaftsbk Bochum"
 
 
 @pytest.mark.parametrize(
@@ -141,7 +143,6 @@ def test_iban_properties():
         (("DE", "43060967", "7000534100"), "DE42430609677000534100"),
         (("DE", "51230800", "2622196545"), "DE61512308002622196545"),
         (("DE", "20690500", "9027378"), "DE37206905000009027378"),
-        (("DE", "75090900", "7408418"), "DE04750909000007408418"),
         (("IT", "0538703601", "000000198036"), "IT18T0538703601000000198036"),
         (("IT", "0538703601", "000000198060"), "IT57V0538703601000000198060"),
         (("IT", "0538703601", "000000198072"), "IT40Z0538703601000000198072"),
@@ -149,16 +150,29 @@ def test_iban_properties():
         (("IT", "0306940101", "100100003599"), "IT94I0306940101100100003599"),
         (("IT", "0335901600", "100000131525"), "IT63M0335901600100000131525"),
         (("IT", "03359", "100000131525", "01600"), "IT63M0335901600100000131525"),
+        (("IT", "39189", "CHTEE9UATVVO", "13896"), "IT12D3918913896CHTEE9UATVVO"),
+        (("IT", "49076", "YB4EQZ0PL4GT", "75919"), "IT70Y4907675919YB4EQZ0PL4GT"),
+        (("IT", "05428", "00ABCD12ZE34", "01600"), "IT21Q054280160000ABCD12ZE34"),
+        (("IT", "05428", "000000123456", "11101"), "IT60X0542811101000000123456"),
+        (("IT", "55354", "AUKNAEXQVZOG", "87408"), "IT77D5535487408AUKNAEXQVZOG"),
+        (("IT", "31582", "YMZJIILHBUN0", "80362"), "IT49B3158280362YMZJIILHBUN0"),
+        (("IT", "39814", "LSLLPTLPK716", "69135"), "IT37W3981469135LSLLPTLPK716"),
+        (("IT", "86388", "3VVRNLLMMN9N", "85779"), "IT69U86388857793VVRNLLMMN9N"),
+        (("IT", "43482", "DNNDKPHAGTIB", "07900"), "IT22K4348207900DNNDKPHAGTIB"),
+        (("IT", "70000", "Mq8gyacBzEqP", "30810"), "IT39M7000030810MQ8GYACBZEQP"),
+        (("IT", "76494", "2Sbpqelox4wG", "16460"), "IT87A76494164602SBPQELOX4WG"),
         (("GB", "NWBK", "31926819", "601613"), "GB29NWBK60161331926819"),
         (("GB", "NWBK", "31926819"), "GB66NWBK00000031926819"),
         (("GB", "NWBK601613", "31926819"), "GB29NWBK60161331926819"),
         (("BE", "050", "123"), "BE66050000012343"),
         (("BE", "050", "123456"), "BE45050012345689"),
         (("BE", "539", "0075470"), "BE68539007547034"),
+        (("FR", "2004101005", "0500013M026"), "FR1420041010050500013M02606"),
     ],
 )
 def test_generate_iban(components, compact):
     iban = IBAN.generate(*components)
+    iban.validate(validate_bban=True)
     assert iban.compact == compact
 
 
@@ -212,6 +226,9 @@ def test_unknown_bic_from_iban():
     assert IBAN("SI72000001234567892").bic is None
 
 
-def test_be_generated_iban_valid():
-    iban = IBAN.generate("BE", bank_code="050", account_code="123456")
-    assert iban.validate(validate_bban=True)
+def test_unknown_bank_name_from_iban():
+    assert IBAN("SI72000001234567892").bank_name is None
+
+
+def test_unknown_bank_name_short_from_iban():
+    assert IBAN("SI72000001234567892").bank_short_name is None
